<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP" sourcelanguage="en">
<context>
    <name>ArtisticSolidColor</name>
    <message>
        <source>Irregular</source>
        <translation>不規則</translation>
    </message>
    <message>
        <source>Horiz Offset</source>
        <translation>水平オフセット</translation>
    </message>
    <message>
        <source>Vert Offset</source>
        <translation>垂直オフセット</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>ノイズ</translation>
    </message>
</context>
<context>
    <name>FlowLineStrokeStyle</name>
    <message>
        <source>Density</source>
        <translation>細線の密度</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>伸長</translation>
    </message>
    <message>
        <source>Width Scale</source>
        <translation>幅の拡大</translation>
    </message>
    <message>
        <source>Straighten Ends</source>
        <translation>端をまっすぐにする</translation>
    </message>
    <message>
        <source>Flow Line</source>
        <translation>フロー線</translation>
    </message>
</context>
<context>
    <name>MovingSolidColor</name>
    <message>
        <source>Offset</source>
        <translation>オフセット</translation>
    </message>
    <message>
        <source>Horiz Offset</source>
        <translation>水平オフセット</translation>
    </message>
    <message>
        <source>Vert Offset</source>
        <translation>垂直オフセット</translation>
    </message>
</context>
<context>
    <name>OutlineViewerStyle</name>
    <message>
        <source>OutlineViewer(OnlyDebug)</source>
        <translation>アウトラインビューア（デバッグのみ）</translation>
    </message>
    <message>
        <source>Control Point</source>
        <translation>コントロールポイント</translation>
    </message>
    <message>
        <source>Center Line</source>
        <translation>中心線</translation>
    </message>
    <message>
        <source>Outline Mode</source>
        <translation>アウトラインモード</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距離</translation>
    </message>
    <message>
        <source>distance</source>
        <translation>距離</translation>
    </message>
</context>
<context>
    <name>ShadowStyle</name>
    <message>
        <source>Hatched Shading</source>
        <translation>ハッチシェード</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>長さ</translation>
    </message>
</context>
<context>
    <name>ShadowStyle2</name>
    <message>
        <source>Plain Shadow</source>
        <translation>影（標準）</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
</context>
<context>
    <name>TAirbrushRasterStyle</name>
    <message>
        <source>Airbrush</source>
        <translation>エアブラシ</translation>
    </message>
    <message>
        <source>Blur value</source>
        <translation>ぼかしの度合</translation>
    </message>
</context>
<context>
    <name>TBiColorStrokeStyle</name>
    <message>
        <source>Shade</source>
        <translation>シェード</translation>
    </message>
</context>
<context>
    <name>TBlendRasterStyle</name>
    <message>
        <source>Blend</source>
        <translation>ブレンド</translation>
    </message>
</context>
<context>
    <name>TBlendStrokeStyle2</name>
    <message>
        <source>Fade</source>
        <translation>フェード</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>境界フェード</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>フェードイン</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>フェードアウト</translation>
    </message>
</context>
<context>
    <name>TBraidStrokeStyle</name>
    <message>
        <source>Plait</source>
        <translation>編みひも</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>回転</translation>
    </message>
</context>
<context>
    <name>TBubbleStrokeStyle</name>
    <message>
        <source>Bubbles</source>
        <translation>泡</translation>
    </message>
</context>
<context>
    <name>TChainStrokeStyle</name>
    <message>
        <source>Chain</source>
        <translation>チェーン</translation>
    </message>
</context>
<context>
    <name>TChalkFillStyle</name>
    <message>
        <source>Chalk</source>
        <translation>チョーク</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Dot Size</source>
        <translation>ドットサイズ</translation>
    </message>
</context>
<context>
    <name>TChalkStrokeStyle2</name>
    <message>
        <source>Chalk</source>
        <translation>チョーク</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>境界フェード</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>フェードイン</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>フェードアウト</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>ノイズ</translation>
    </message>
</context>
<context>
    <name>TCheckedFillStyle</name>
    <message>
        <source>Square</source>
        <translation>四角模様</translation>
    </message>
    <message>
        <source>Horiz Dist</source>
        <translation>水平距離</translation>
    </message>
    <message>
        <source>Horiz Angle</source>
        <translation>水平角</translation>
    </message>
    <message>
        <source>Vert Dist</source>
        <translation>垂直距離</translation>
    </message>
    <message>
        <source>Vert Angle</source>
        <translation>垂直角</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>厚さ</translation>
    </message>
</context>
<context>
    <name>TChessFillStyle</name>
    <message>
        <source>Chessboard</source>
        <translation>チェス盤</translation>
    </message>
    <message>
        <source>Horiz Size</source>
        <translation>水平サイズ</translation>
    </message>
    <message>
        <source>Vert Size</source>
        <translation>垂直サイズ</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
</context>
<context>
    <name>TCircleStripeFillStyle</name>
    <message>
        <source>Concentric</source>
        <translation>同心円</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>水平位置</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>垂直位置</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距離</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>太さ</translation>
    </message>
</context>
<context>
    <name>TCrystallizeStrokeStyle</name>
    <message>
        <source>Tulle</source>
        <translation>チュール</translation>
    </message>
    <message>
        <source>Crease</source>
        <translation>折り目</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>不透明度</translation>
    </message>
</context>
<context>
    <name>TDottedFillStyle</name>
    <message>
        <source>Polka Dots</source>
        <translation>水玉模様</translation>
    </message>
    <message>
        <source>Dot Size</source>
        <translation>水玉のサイズ</translation>
    </message>
    <message>
        <source>Dot Distance</source>
        <translation>水玉の距離</translation>
    </message>
</context>
<context>
    <name>TDottedLineStrokeStyle</name>
    <message>
        <source>Vanishing</source>
        <translation>減衰</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>フェードイン</translation>
    </message>
    <message>
        <source>Dash</source>
        <translation>線の部分</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>フェードアウト</translation>
    </message>
    <message>
        <source>Gap</source>
        <translation>空白の部分</translation>
    </message>
</context>
<context>
    <name>TDualColorStrokeStyle2</name>
    <message>
        <source>Striped</source>
        <translation>縞</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距離</translation>
    </message>
</context>
<context>
    <name>TFriezeStrokeStyle2</name>
    <message>
        <source>Curl</source>
        <translation>カール</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>回転</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>太さ</translation>
    </message>
</context>
<context>
    <name>TFurStrokeStyle</name>
    <message>
        <source>Herringbone</source>
        <translation>ヘリンボーン</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
</context>
<context>
    <name>TGraphicPenStrokeStyle</name>
    <message>
        <source>Dashes</source>
        <translation>ストローク</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
</context>
<context>
    <name>TLinGradFillStyle</name>
    <message>
        <source>Linear Gradient</source>
        <translation>線形グラデーション</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>水平位置</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>垂直位置</translation>
    </message>
    <message>
        <source>Smoothness</source>
        <translation>滑らかさ</translation>
    </message>
</context>
<context>
    <name>TLongBlendStrokeStyle2</name>
    <message>
        <source>Watercolor</source>
        <translation>水彩画</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>TMatrioskaStrokeStyle</name>
    <message>
        <source>Toothpaste</source>
        <translation>練り歯磨き</translation>
    </message>
    <message>
        <source>Stripes</source>
        <translation>縞</translation>
    </message>
</context>
<context>
    <name>TMosaicFillStyle</name>
    <message>
        <source>Stained Glass</source>
        <translation>ステンドグラス</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <source>Distortion</source>
        <translation>ゆがみ</translation>
    </message>
    <message>
        <source>Min Thick</source>
        <translation>厚さの最小値</translation>
    </message>
    <message>
        <source>Max Thick</source>
        <translation>厚さの最大値</translation>
    </message>
</context>
<context>
    <name>TMultiLineStrokeStyle2</name>
    <message>
        <source>Gouache</source>
        <translation>グワッシュ</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>太さ</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>ノイズ</translation>
    </message>
</context>
<context>
    <name>TNoColorRasterStyle</name>
    <message>
        <source>Markup</source>
        <translation>マークアップ</translation>
    </message>
</context>
<context>
    <name>TNormal2StrokeStyle</name>
    <message>
        <source>Bump</source>
        <translation>バンプ</translation>
    </message>
    <message>
        <source>Light X Pos</source>
        <translation>光源の水平位置</translation>
    </message>
    <message>
        <source>Light Y Pos</source>
        <translation>光源の垂直位置</translation>
    </message>
    <message>
        <source>Shininess</source>
        <translation>光沢度</translation>
    </message>
    <message>
        <source>Plastic</source>
        <translation>プラスチック</translation>
    </message>
</context>
<context>
    <name>TPatchFillStyle</name>
    <message>
        <source>Beehive</source>
        <translation>蜂の巣模様</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <source>Distortion</source>
        <translation>ゆがみ</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>太さ</translation>
    </message>
</context>
<context>
    <name>TPointShadowFillStyle</name>
    <message>
        <source>Sponge Shading</source>
        <translation>スポンジシェード</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <source>Point Size</source>
        <translation>ポイントサイズ</translation>
    </message>
</context>
<context>
    <name>TRadGradFillStyle</name>
    <message>
        <source>Radial Gradient</source>
        <translation>円形グラデーション</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>水平位置</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>垂直位置</translation>
    </message>
    <message>
        <source>Radius</source>
        <translation>半径</translation>
    </message>
    <message>
        <source>Smoothness</source>
        <translation>滑らかさ</translation>
    </message>
</context>
<context>
    <name>TRopeStrokeStyle</name>
    <message>
        <source>Rope</source>
        <translation>ロープ</translation>
    </message>
    <message>
        <source>Tilt</source>
        <translation>傾斜</translation>
    </message>
</context>
<context>
    <name>TRubberFillStyle</name>
    <message>
        <source>Blob</source>
        <translation>ブロッブ</translation>
    </message>
    <message>
        <source>Intensity</source>
        <translation>強度</translation>
    </message>
</context>
<context>
    <name>TSawToothStrokeStyle</name>
    <message>
        <source>Jagged</source>
        <translation>ぎざぎざの度合</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距離</translation>
    </message>
</context>
<context>
    <name>TSinStrokeStyle</name>
    <message>
        <source>Wave</source>
        <translation>波</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>周波数</translation>
    </message>
</context>
<context>
    <name>TSketchStrokeStyle</name>
    <message>
        <source>Fuzz</source>
        <translation>ぼかし具合</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
</context>
<context>
    <name>TSprayStrokeStyle</name>
    <message>
        <source>Circlets</source>
        <translation>小さい円</translation>
    </message>
    <message>
        <source>Border Fade</source>
        <translation>境界フェード</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
</context>
<context>
    <name>TStripeFillStyle</name>
    <message>
        <source>Banded</source>
        <translation>縞模様</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>距離</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>太さ</translation>
    </message>
</context>
<context>
    <name>TTissueStrokeStyle</name>
    <message>
        <source>Gauze</source>
        <translation>網目模様</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>密度</translation>
    </message>
    <message>
        <source>Border Size</source>
        <translation>境界のサイズ</translation>
    </message>
</context>
<context>
    <name>TTwirlStrokeStyle</name>
    <message>
        <source>Ribbon</source>
        <translation>リボン</translation>
    </message>
    <message>
        <source>Twirl</source>
        <translation>回転</translation>
    </message>
    <message>
        <source>Shade</source>
        <translation>影</translation>
    </message>
</context>
<context>
    <name>TZigzTSinStrokeStyleagStrokeStyle</name>
    <message>
        <source>Thickness</source>
        <translation>太さ</translation>
    </message>
</context>
<context>
    <name>TZigzagStrokeStyle</name>
    <message>
        <source>Zigzag</source>
        <translation>ジグザグ</translation>
    </message>
    <message>
        <source>Min Distance</source>
        <translation>距離の最小値</translation>
    </message>
    <message>
        <source>Max Distance</source>
        <translation>距離の最大値</translation>
    </message>
    <message>
        <source>Min Angle</source>
        <translation>角度の最大値</translation>
    </message>
    <message>
        <source>Max Angle</source>
        <translation>角度の最大値</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>太さ</translation>
    </message>
</context>
</TS>
